20XX
---

20XX is a PettingZoo-based library for Melee. (⌐■_■)

## Note
This library requires Slippi, which in turn requires an SSBM 1.02 NTSC/PAL ISO. This library does not and will not distribute this. You must acquire this on your own!

## Installation
`pip install 20XX`
`pip install git+https://github.com/WillDudley/libmelee.git`  (fixes some menu handling issues)

## Credits
- Heavily relies on [libmelee](https://github.com/altf4/libmelee),
- uses [PettingZoo](https://pettingzoo.farama.org),
- originally forked from [melee-env](https://github.com/davidtjones/melee-env).
